@@ -24,9 +24,18 @@
 #include <unistd.h>
 
 int main(int argc, char **argv){
-	
+
 	general_stat_t *general_stats;
 
+	/* Initialise statgrab */
+	statgrab_init();
+
+	/* Drop setuid/setgid privileges. */
+	if (statgrab_drop_privileges() != 0) {
+		perror("Error. Failed to drop privileges");
+		return 1;
+	}
+
 	general_stats = get_general_stats();
 
 	if(general_stats == NULL){
@@ -43,6 +52,3 @@ int main(int argc, char **argv){
 
 	exit(0);
 }
-
-
-
