@@ -24,22 +24,31 @@
 #include <unistd.h>
 
 int main(int argc, char **argv){
-	
+
 	extern char *optarg;
-        extern int optind;
-        int c;
+	extern int optind;
+	int c;
 
 	int delay = 1;
 	page_stat_t *page_stats;
 
-	while ((c = getopt(argc, argv, "d:")) != EOF){
-                switch (c){
-                        case 'd':
-                                delay = atoi(optarg);
-                                break;
+	while ((c = getopt(argc, argv, "d:")) != -1){
+		switch (c){
+			case 'd':
+				delay = atoi(optarg);
+				break;
 		}
 	}
 
+	/* Initialise statgrab */
+	statgrab_init();
+
+	/* Drop setuid/setgid privileges. */
+	if (statgrab_drop_privileges() != 0) {
+		perror("Error. Failed to drop privileges");
+		return 1;
+	}
+
 	while( (page_stats = get_page_stats_diff()) != NULL){
 		printf("Pages in : %lld\n", page_stats->pages_pagein);
 		printf("Pages out : %lld\n", page_stats->pages_pageout);
@@ -48,6 +57,3 @@ int main(int argc, char **argv){
 
 	exit(0);
 }
-
-
-
