@@ -24,10 +24,10 @@
 #include <unistd.h>
 
 int main(int argc, char **argv){
-	
+
 	extern char *optarg;
-        extern int optind;
-        int c;
+	extern int optind;
+	int c;
 
 	int delay = 1;
 	mem_stat_t *mem_stats;
@@ -35,14 +35,23 @@ int main(int argc, char **argv){
 
 	long long total, free;
 
-	while ((c = getopt(argc, argv, "d:")) != EOF){
-                switch (c){
-                        case 'd':
-                                delay = atoi(optarg);
-                                break;
+	while ((c = getopt(argc, argv, "d:")) != -1){
+		switch (c){
+			case 'd':
+				delay = atoi(optarg);
+				break;
 		}
 	}
 
+	/* Initialise statgrab */
+	statgrab_init();
+
+	/* Drop setuid/setgid privileges. */
+	if (statgrab_drop_privileges() != 0) {
+		perror("Error. Failed to drop privileges");
+		return 1;
+	}
+
 	if( ((mem_stats=get_memory_stats()) != NULL) && (swap_stats=get_swap_stats()) != NULL){
 		printf("Total memory in bytes : %lld\n", mem_stats->total);
 		printf("Used memory in bytes : %lld\n", mem_stats->used);
@@ -61,6 +70,3 @@ int main(int argc, char **argv){
 	}
 	exit(0);
 }
-
-
-
