@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include "statgrab.h"
 
 #ifdef SOLARIS
@@ -34,11 +35,13 @@
 #define VALID_FS_TYPES {"ufs", "tmpfs"}
 #endif
 
-#ifdef LINUX
-#include <time.h>
-#include <sys/vfs.h>
+#if defined(LINUX) || defined(CYGWIN)
 #include <mntent.h>
+#include <sys/vfs.h>
 #include "tools.h"
+#endif
+
+#ifdef LINUX
 #define VALID_FS_TYPES {"adfs", "affs", "befs", "bfs", "efs", "ext2", \
                         "ext3", "vxfs", "hfs", "hfsplus", "hpfs", "jffs", \
                         "jffs2", "minix", "msdos", "ntfs", "qnx4", "ramfs", \
@@ -46,6 +49,10 @@
                         "umsdos", "vfat", "xfs", "jfs"}
 #endif
 
+#ifdef CYGWIN
+#define VALID_FS_TYPES {"user"}
+#endif
+
 #ifdef ALLBSD
 #include <sys/param.h>
 #include <sys/ucred.h>
@@ -91,15 +98,26 @@ void init_disk_stat(int start, int end, disk_stat_t *disk_stats){
 	}
 }
 
+int is_valid_fs_type(const char *type) {
+	const char *types[] = VALID_FS_TYPES;
+	int i;
+
+	for (i = 0; i < (sizeof types / sizeof *types); i++) {
+		if (strcmp(types[i], type) == 0) {
+			return 1;
+		}
+	}
+	return 0;
+}
+
 disk_stat_t *get_disk_stats(int *entries){
 
 	static disk_stat_t *disk_stats;
 	static int watermark=-1;
 
-	char *fs_types[] = VALID_FS_TYPES;
-	int x, valid_type;
+	int valid_type;
 	int num_disks=0;
-#if defined(LINUX) || defined (SOLARIS)
+#if defined(LINUX) || defined (SOLARIS) || defined(CYGWIN)
 	FILE *f;
 #endif
 
@@ -109,7 +127,7 @@ disk_stat_t *get_disk_stats(int *entries){
 	struct mnttab mp;
 	struct statvfs fs;
 #endif
-#ifdef LINUX
+#if defined(LINUX) || defined(CYGWIN)
 	struct mntent *mp;
 	struct statfs fs;
 #endif
@@ -132,16 +150,10 @@ disk_stat_t *get_disk_stats(int *entries){
 		return NULL;
 	}
 	for(;nummnt--; mp++){
-		valid_type=0;
-		for(x=0;x<((sizeof(fs_types))/(sizeof(char*)));x++){
-                        if(strcmp(mp->f_fstypename, fs_types[x]) ==0){
-                                valid_type=1;
-                                break;
-                        }
-                }
+		valid_type = is_valid_fs_type(mp->f_fstypename);
 #endif
 
-#ifdef LINUX
+#if defined(LINUX) || defined(CYGWIN)
 	if ((f=setmntent("/etc/mtab", "r" ))==NULL){
 		return NULL;
 	}
@@ -151,13 +163,7 @@ disk_stat_t *get_disk_stats(int *entries){
 			continue;
 		}	
 
-		valid_type=0;
-		for(x=0;x<((sizeof(fs_types))/(sizeof(char*)));x++){
-                        if(strcmp(mp->mnt_type, fs_types[x]) ==0){
-                                valid_type=1;
-                                break;
-                        }
-                }
+		valid_type = is_valid_fs_type(mp->mnt_type);
 #endif
 
 #ifdef SOLARIS
@@ -168,13 +174,7 @@ disk_stat_t *get_disk_stats(int *entries){
 		if ((statvfs(mp.mnt_mountp, &fs)) !=0){
 			continue;
 		}
-		valid_type=0;
-		for(x=0;x<((sizeof(fs_types))/(sizeof(char*)));x++){
-			if(strcmp(mp.mnt_fstype, fs_types[x]) ==0){
-				valid_type=1;
-				break;
-			}
-		}
+		valid_type = is_valid_fs_type(mp.mnt_fstype);
 #endif
 
 		if(valid_type){
@@ -212,7 +212,7 @@ disk_stat_t *get_disk_stats(int *entries){
 			/* Freebsd doesn't have a "available" inodes */
 			disk_ptr->used_inodes=disk_ptr->total_inodes-disk_ptr->free_inodes;
 #endif
-#ifdef LINUX
+#if defined(LINUX) || defined(CYGWIN)
 			if((disk_ptr->device_name=copy_string(disk_ptr->device_name, mp->mnt_fsname))==NULL){
 				return NULL;
 			}
@@ -266,8 +266,12 @@ disk_stat_t *get_disk_stats(int *entries){
 
 	*entries=num_disks;	
 
-	/* If this fails, there is very little i can do about it, so i'll ignore it :) */
-#if defined(LINUX) || defined(SOLARIS)
+	/* If this fails, there is very little i can do about it, so
+           I'll ignore it :) */
+#if defined(LINUX) || defined(CYGWIN)
+	endmntent(f);
+#endif
+#if defined(SOLARIS)
 	fclose(f);
 #endif
 
@@ -322,7 +326,9 @@ typedef struct {
 diskio_stat_t *get_diskio_stats(int *entries){
 
 	static int sizeof_diskio_stats=0;
+#ifndef LINUX
 	diskio_stat_t *diskio_stats_ptr;
+#endif
 
 #ifdef SOLARIS
         kstat_ctl_t *kc;
@@ -333,12 +339,12 @@ diskio_stat_t *get_diskio_stats(int *entries){
 	FILE *f;
 	char *line_ptr;
 	int major, minor;
-	char dev_letter;
 	int has_pp_stats = 1;
 	static partition *parts = NULL;
 	static int alloc_parts = 0;
 	int i, n;
 	time_t now;
+	const char *format;
 #endif
 #ifdef FREEBSD
 	static struct statinfo stats;
@@ -497,7 +503,7 @@ diskio_stat_t *get_diskio_stats(int *entries){
 
 			if(diskio_stats_ptr->disk_name!=NULL) free(diskio_stats_ptr->disk_name);
 
-			diskio_stats_ptr->disk_name=strdup(ksp->ks_name);
+			diskio_stats_ptr->disk_name=strdup((char *) get_svr_from_bsd(ksp->ks_name));
 			diskio_stats_ptr->systime=time(NULL);
 			num_diskio++;
 		}
@@ -511,9 +517,16 @@ diskio_stat_t *get_diskio_stats(int *entries){
 	n = 0;
 
 	/* Read /proc/partitions to find what devices exist. Recent 2.4 kernels
-	   have statistics in here too, so we can use those directly. */
+	   have statistics in here too, so we can use those directly.
+	   2.6 kernels have /proc/diskstats instead with almost (but not quite)
+	   the same format. */
 
-	f = fopen("/proc/partitions", "r");
+	f = fopen("/proc/diskstats", "r");
+	format = " %d %d %19s %*d %*d %lld %*d %*d %*d %lld";
+	if (f == NULL) {
+		f = fopen("/proc/partitions", "r");
+		format = " %d %d %*d %19s %*d %*d %lld %*d %*d %*d %lld";
+	}
 	if (f == NULL) goto out;
 	now = time(NULL);
 
@@ -522,15 +535,9 @@ diskio_stat_t *get_diskio_stats(int *entries){
 		char *s;
 		long long rsect, wsect;
 
-		int nr = sscanf(line_ptr,
-			" %d %d %*d %19s %*d %*d %lld %*d %*d %*d %lld",
+		int nr = sscanf(line_ptr, format,
 			&major, &minor, name, &rsect, &wsect);
 		if (nr < 3) continue;
-		if (nr < 5) {
-			has_pp_stats = 0;
-			rsect = 0;
-			wsect = 0;
-		}
 
 		/* Skip device names ending in numbers, since they're
 		   partitions. */
@@ -539,6 +546,12 @@ diskio_stat_t *get_diskio_stats(int *entries){
 		--s;
 		if (*s >= '0' && *s <= '9') continue;
 
+		if (nr < 5) {
+			has_pp_stats = 0;
+			rsect = 0;
+			wsect = 0;
+		}
+
 		diskio_stats = diskio_stat_malloc(n + 1, &sizeof_diskio_stats,
 			diskio_stats);
 		if (diskio_stats == NULL) goto out;
@@ -632,8 +645,12 @@ diskio_stat_t *get_diskio_stats(int *entries){
 	num_diskio = n;
 out:
 	if (f != NULL) fclose(f);
-
 #endif
+
+#ifdef CYGWIN
+	return NULL;
+#endif
+
 	*entries=num_diskio;
 
 	return diskio_stats;
