@@ -34,12 +34,17 @@ load_stat_t *get_load_stats(){
 	static load_stat_t load_stat;
 
 	double loadav[3];
-  	getloadavg(loadav,3);
+
+#ifdef CYGWIN
+	return NULL;
+#else
+
+	getloadavg(loadav,3);
 
 	load_stat.min1=loadav[0];
 	load_stat.min5=loadav[1];
 	load_stat.min15=loadav[2];
 
 	return &load_stat;
-
+#endif
 }
