@@ -39,7 +39,7 @@
 #define MAX_FILE_LENGTH PATH_MAX
 #endif
 #ifdef LINUX
-#include <linux/limits.h>
+#include <limits.h>
 #define PROC_LOCATION "/proc"
 #define MAX_FILE_LENGTH PATH_MAX
 #endif
@@ -162,6 +162,10 @@ process_stat_t *get_process_stats(){
 	}
 #endif
 
+#ifdef CYGWIN
+	return NULL;
+#endif
+
 	process_stat.total=process_stat.sleeping+process_stat.running+process_stat.zombie+process_stat.stopped;
 
 	return &process_stat;
