@@ -19,6 +19,12 @@
  */
 
 #include <sys/types.h>
+#ifdef NETBSD
+#include <limits.h>
+#endif
+#ifdef CYGWIN
+#include <sys/unistd.h>
+#endif
 
 typedef struct{
         long long user;
@@ -60,6 +66,12 @@ typedef struct{
 #if defined(LINUX) || defined(FREEBSD)
 #define MAX_LOGIN_NAME_SIZE UT_NAMESIZE
 #endif
+#ifdef NETBSD
+#define MAX_LOGIN_NAME_SIZE _POSIX_LOGIN_NAME_MAX
+#endif
+#if defined(CYGWIN)
+#define MAX_LOGIN_NAME_SIZE _SC_LOGIN_NAME_MAX
+#endif
 
 typedef struct{
 	char *name_list;
@@ -148,3 +160,5 @@ page_stat_t *get_page_stats();
 page_stat_t *get_page_stats_diff();
 
 int statgrab_init(void);
+int statgrab_drop_privileges(void);
+
