@@ -29,8 +29,9 @@
 #include <sys/swap.h>
 #include <unistd.h>
 #endif
-#ifdef LINUX
+#if defined(LINUX) || defined(CYGWIN)
 #include <stdio.h>
+#include <string.h>
 #endif
 #ifdef FREEBSD
 #include <unistd.h>
@@ -46,9 +47,10 @@ swap_stat_t *get_swap_stats(){
 	struct anoninfo ai;
 	int pagesize;
 #endif
-#ifdef LINUX
+#if defined(LINUX) || defined(CYGWIN)
 	FILE *f;
 	char *line_ptr;
+	unsigned long long value;
 #endif
 #ifdef FREEBSD
 	struct kvm_swap swapinfo;
@@ -70,19 +72,26 @@ swap_stat_t *get_swap_stats(){
 	swap_stat.used = (long long)ai.ani_resv * (long long)pagesize;
 	swap_stat.free = swap_stat.total - swap_stat.used;
 #endif
-#ifdef LINUX
-	if ((f=fopen("/proc/meminfo", "r" ))==NULL) {
+#if defined(LINUX) || defined(CYGWIN)
+	if ((f = fopen("/proc/meminfo", "r")) == NULL) {
 		return NULL;
 	}
-	if((line_ptr=f_read_line(f, "Swap:"))==NULL){
-		fclose(f);
-		return NULL;
-	}
-	if((sscanf(line_ptr, "Swap: %lld %lld %lld", &swap_stat.total, &swap_stat.used, &swap_stat.free))!=3){
-		fclose(f);
-		return NULL;
+
+	while ((line_ptr = f_read_line(f, "")) != NULL) {
+		if (sscanf(line_ptr, "%*s %llu kB", &value) != 1) {
+			continue;
+		}
+		value *= 1024;
+
+		if (strncmp(line_ptr, "SwapTotal:", 10) == 0) {
+			swap_stat.total = value;
+		} else if (strncmp(line_ptr, "SwapFree:", 9) == 0) {
+			swap_stat.free = value;
+		}
 	}
+
 	fclose(f);
+	swap_stat.used = swap_stat.total - swap_stat.free;
 #endif
 #ifdef FREEBSD
 	if((kvmd = get_kvm()) == NULL){
